import random
from pathlib import Path
from flask import Flask, request, render_template, redirect, send_file

from imagetools.lib.constants import TEMPLATE_FOLDER, SEPARATOR
from imagetools.lib.exif import get_date, is_image
from imagetools.lib.filesystem import touch_file, append_to_file, filter_ls

flask = Flask(__name__, template_folder=TEMPLATE_FOLDER)

def _not_already_sorted(file_path: Path):
    """
    Checks if a given file has been
    """
    filter_file = flask.config.get("filter_file")
    touch_file(filter_file)

    with open(filter_file, "r") as f:
        for line in f.readlines():
            file, _ = line.split(SEPARATOR)

            if file == file_path:
                return False

    return True


def _adjacent_dates(file: Path) -> list[tuple[Path, str]]:
    """
    Gets the EXIF data from files within the same directory as a given file.

    :param file: The path of an image
    :returns: List containing [filename, date] tuples of adjacent files.
    """

    return [
        [i, get_date(i, allow_none=True)]
        for i in filter_ls(file.parent)
    ]


@flask.get("/")
def get():

    files_to_date = [
        i
        for j in flask.config.get("base_folders")
        for i in filter_ls(j, _not_already_sorted)
    ]

    image = random.choice(files_to_date)

    template = "image.html" if is_image(image) else "video.html"

    return render_template(
        template,
        path=str(image),
        adjacent=_adjacent_dates(image),
        count=len(files_to_date),
    )


@flask.get("/file")
def get_file():
    path_param = request.args.get("path")
    return send_file(path_param)


@flask.post("/date")
def post_date():
    d = request.form

    append_to_file(
        flask.config.get("filter_file"),
        f"{d['path']}{SEPARATOR}{d['date']} {d['time']}",
    )

    return redirect("/")


@flask.post("/delete")
def post_delete():
    d = request.form

    append_to_file(flask.config.get("filter_file"), f"{d['path']}{SEPARATOR}DELETE")

    return redirect("/")
